class PurseType(object):
    TYPE_WEBMONEY = 'WebMoney'
    TYPE_YANDEX_MONEY = 'Yandex'
    TYPE_QIWI = 'QIWI'
    TYPE_ZALEY_CASH = 'ZaleyCash'
    TYPE_RU_CARD = 'RUCARD'
    TYPE_UKR_CARD = 'UKRCARD'
    TYPE_WORLD_CARD = 'WORLDCARD'
    TYPE_CIS_CARD = 'SNGCARD'
    TYPE_MTS = 'MTS'
    TYPE_BEELINE = 'Beeline'
    TYPE_MEGAFON = 'MegaFon'
    TYPE_TELE2 = 'Tele2'
    TYPE_CAPITALIST = 'Capitalist'


class Currency(object):
    RUB = 'RUB'
    USD = 'USD'
    EURO = 'EUR'
